# Copyright 2008-2018 Rumma & Ko Ltd
# License: GNU Affero General Public License v3 (see file COPYING for details)

"""These are the plugins included with Lino XL.

See also :doc:`/plugins/index`.

Contacts management
===================

.. autosummary::
   :toctree:

    countries
    contacts
    addresses
    phones
    households
    humanlinks
    cv
    dupable_partners

Groupware
=========

.. autosummary::
   :toctree:

    boards
    teams
    lists
    groups
    topics
    deploy
    tickets
    skills
    working
    votes


Calendar functionalities
========================

.. autosummary::
   :toctree:

    cal
    calview
    extensible
    reception
    rooms
    courses


Office functionalities
======================

.. autosummary::
   :toctree:

    notes
    outbox
    postings
    mailbox
    caldav

ERP
===

.. autosummary::
   :toctree:

    products
    orders
    shopping

System extensions
=================

.. autosummary::
   :toctree:

    appypod
    excerpts
    stars
    userstats


Miscellaneous
=============

.. autosummary::
   :toctree:

    beid
    polls
    clients
    coachings
    trends

Content management
==================

.. autosummary::
   :toctree:

    blogs
    pages

Accounting stuff
================

.. autosummary::
   :toctree:

    b2c
    ledger
    sales
    finan
    tim2lino
    sepa
    invoicing
    vatless
    bevat
    bevats
    eevat
    ana
    sheets

The following plugins are already migrated to full narrative docs
:mod:`lino_xl.lib.vat`

Plugin namespaces
=======================

(See :ref:`plugin_namespaces`).

.. autosummary::
   :toctree:

    statbel
    online

Experimental and not much used
==============================

.. autosummary::
   :toctree:

    concepts
    eid_jslib
    thirds
    events
    families
    properties
    inspect

"""
